from setuptools import setup, find_packages

setup(
    name="Kadrajan",
    version="1.0.1",
    packages=find_packages(),
    install_requires=[],
    description="Python için ilk kütüphanem",
    author="Poyraz",
    python_requires='>=3.6',
)